

# The Multi-Agent Arcade Learning Environment


## Overview

This is a fork of the [Arcade Learning Environment (ALE)](https://github.com/mgbellemare/Arcade-Learning-Environment). It is mostly backwards compatible with ALE and it also supports certain games with 2 and 4 players.

To install it in Python, please use `pip install multi-agent-ale-py`
